@@ -21,12 +21,36 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 DEALINGS IN THE SOFTWARE.
 """
+
 import inspect
 
-class ReactionMenuException(Exception):
-	"""Base Reaction Menu exception"""
+class ButtonsMenuException(Exception):
+	"""Base :class:`ButtonsMenu` exception
+	
+		.. added:: v1.1.0
+	"""
 	pass
 
+class ReactionMenuException(Exception):
+	"""Base :class:`ReactionMenu` exception"""
+	pass
+
+class IncorrectType(ReactionMenuException):
+	"""Raised when the expected type was not given
+	
+		.. added:: v1.0.9
+	"""
+	def __init__(self, message: str):
+		super().__init__(message)
+
+class NoButtons(ReactionMenuException):
+	"""Raised when the menu was started but no buttons were registered or the action initiated requires buttons to be registered
+
+		.. added:: v1.0.9
+	"""
+	def __init__(self, message: str='You cannot start the menu when no buttons are registered'):
+		super().__init__(message)
+
 class InvalidPage(ReactionMenuException):
 	"""Raised when the page selected to remove does not exist"""
 	pass
@@ -67,8 +91,8 @@ class ImproperButtonOrderChange(ReactionMenuException):
 
 class TooManyButtons(ReactionMenuException):
 	"""The amount of buttons registered is > 20 (over discords reaction limit)"""
-	def __init__(self):
-		super().__init__('Discord currently has a limit of 20 reactions or less per message. Remove 1 or more buttons')
+	def __init__(self, message: str='Discord currently has a limit of 20 reactions or less per message. Remove 1 or more buttons'):
+		super().__init__(message)
 
 class MissingSetting(ReactionMenuException):
 	"""Raised when an action requires specific input from the user"""
@@ -76,8 +100,8 @@ class MissingSetting(ReactionMenuException):
 
 class NoPages(ReactionMenuException):
 	"""Tried to start the menu when they haven't added any pages"""
-	def __init__(self):
-		super().__init__('You cannot start a reaction menu when there aren\'t any pages')
+	def __init__(self, message: str="You cannot start a reaction menu when there aren't any pages"):
+		super().__init__(message)
 
 class MenuAlreadyRunning(ReactionMenuException):
 	"""Called a method that is not allowed to be called after the menu has started"""
@@ -86,4 +110,4 @@ class MenuAlreadyRunning(ReactionMenuException):
 
 class ButtonNotFound(ReactionMenuException):
 	"""Raised when the :meth:ReactionMenu.remove_button did not find any matching buttons"""
-	pass
\ No newline at end of file
+	pass
